/*
 *      userdialog.cpp
 *
 *      Copyright 2014 David Vachulka <arch_dvx@users.sourceforge.net>
 *
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 3 of the License, or
 *      (at your option) any later version.
 *
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *      MA 02110-1301, USA.
 */

#include "userdialog.h"
#include "config.h"
#include "i18n.h"
#include "dxutils.h"

UserDialog::UserDialog(bool frien, QWidget *parent)
: QDialog(parent)
{
    if(frien) createGUI("example","#dxirc,#prd","freenode");
    else createGUI("_example!example@example.com", "all", "all");
    setWindowTitle(frien?_("Add friend"):_("Add ignore user"));
}

UserDialog::UserDialog(bool frien, const QString &nick, const QString &channels, const QString &server, bool add, QWidget *parent)
: QDialog(parent)
{
    createGUI(nick, channels, server);
    if(frien) setWindowTitle(add?_("Add friend"):_("Modify friend"));
    else setWindowTitle(add?_("Add ignore user"):_("Edit ignore user"));
}

void UserDialog::createGUI(const QString &nick, const QString &channels, const QString &server)
{
    QGridLayout *matrix = new QGridLayout;
    int i = 0;
    matrix->addWidget(new QLabel(_("Nick:")), i, 0);
    m_nick = new QLineEdit(nick);
    matrix->addWidget(m_nick, i, 1);
    i++;
    matrix->addWidget(new QLabel(_("Channel(s):")), i, 0);
    m_channels = new QLineEdit(channels);
    m_channels->setToolTip(_("Channels need to be comma separated"));
    matrix->addWidget(m_channels, i, 1);
    i++;
    matrix->addWidget(new QLabel(_("Network:")), i, 0);
    m_server = new QLineEdit(server);
    matrix->addWidget(m_server, i, 1);
    QDialogButtonBox *buttons = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
    connect(buttons, SIGNAL(accepted()), this, SLOT(accept()));
    connect(buttons, SIGNAL(rejected()), this, SLOT(reject()));
    QVBoxLayout *mainFrame = new QVBoxLayout(this);
    mainFrame->addLayout(matrix);
    mainFrame->addWidget(buttons);
    setLayout(mainFrame);
}


