/*
 *      dccengine.h
 *
 *      Copyright 2014 David Vachulka <arch_dvx@users.sourceforge.net>
 *
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 3 of the License, or
 *      (at your option) any later version.
 *
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *      MA 02110-1301, USA.
 */


#ifndef DCCENGINE_H
#define DCCENGINE_H

#include <fstream>
#include "defs.h"
#include "ircengine.h"

class DccEngine : public QObject
{
    Q_OBJECT
public:
    DccEngine(DccFile file, IrcEngine *engine);
    virtual ~DccEngine();
    
    void startConnection();
    void disconnect();
    bool setDccPosition(quint32 position);
    bool isForResume(const QString& nick, const QString& name, int port);
    bool isForResume(int token);
    DccFile getDccFile() { return m_file; }
    bool hasDccFile(DccFile file) { return m_file == file; }
signals:
    void dccError(QString);
    void dccPosition(DccFile);
private:
    DccEngine() {}

    DccFile m_file;
    IrcEngine *m_engine;
    dxSocket *m_socket;
    bool m_connected;
    std::ofstream m_receivedFile;
    std::ifstream m_sentFile;
    bool m_positionChanged; // data arrived or sended between updateDcc
    qlonglong m_lastChange; // timestamp for m_positionChanged==TRUE
    quint32 m_dataAmount; // amount of arrived or sended data
    int m_dccTimeout;
    QTimer *m_timerClose;
    QTimer *m_timerPosition;

    void readData();
    void writeData();
    void closeFile();
    void updateDcc();
private slots:
    void slotCloseTimeout();
    void slotPositionTimeout();
    void slotCanRead();
    void slotWritten(qint64);
    void slotConnected();
    void slotDisconnected();
    void slotError(QString);
    void slotStartAccept(int);
    void slotListen();
};

#endif // DCCENGINE_H
