/*
 *      ircitemmodel.cpp
 *
 *      Copyright 2014 David Vachulka <arch_dvx@users.sourceforge.net>
 *
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 3 of the License, or
 *      (at your option) any later version.
 *
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *      MA 02110-1301, USA.
 */

#include "ircitemmodel.h"
#include "dxutils.h"
#include "preferences.h"
#include "ircitem.h"

IrcItemModel::IrcItemModel(QObject* parent) :
    QStandardItemModel(parent)
{
}

IrcItem* IrcItemModel::getItem(const QString &nick)
{
    for(int r = 0; r < rowCount(); ++r)
    {
        IrcItem *i = static_cast<IrcItem*>(item(r));
        if(i->getNick() == nick)
            return i;
    }
    return 0;
}

QString IrcItemModel::getItemNick(int row) const
{
    for(int r = 0; r < rowCount(); ++r)
    {
        IrcItem *i = static_cast<IrcItem*>(item(r));
        if(row == r)
            return i->getNick();
    }
    return "";
}

bool IrcItemModel::hasItem(const QString &nick)
{
    for(int r = 0; r < rowCount(); ++r)
    {
        IrcItem *i = static_cast<IrcItem*>(item(r));
        if(i->getNick() == nick)
            return true;
    }
    return false;
}

void IrcItemModel::addItem(const QString &nick, UserMode mode)
{
    IrcItem *item = new IrcItem(nick, mode);
    appendRow(item);
}

void IrcItemModel::removeItem(const QString &nick)
{
    IrcItem *item = getItem(nick);
    if(item)
        removeRow(item->row());
}

void IrcItemModel::updateItem(const QString &nick, UserMode mode)
{
    IrcItem *item = getItem(nick);
    if(item)
    {
        item->setText(nick);
        item->setMode(mode);
    }
}

void IrcItemModel::updateItem(const QString& nick, NickInfo info)
{
    IrcItem *item = getItem(nick);
    if(item)
    {
        item->setText(nick);
        item->updateTooltip(info);
    }
}

void IrcItemModel::updateItem(const QString& nick, const QString& newnick, NickInfo info)
{
    IrcItem *item = getItem(nick);
    if(item)
    {
        item->setText(newnick);
        item->updateTooltip(info);
    }
}

void IrcItemModel::updateAway(const QString& nick, bool away)
{
    IrcItem *item = getItem(nick);
    if(item)
    {
        item->setAway(away);
    }
}

void IrcItemModel::clear()
{
    QStandardItemModel::clear();
}

void IrcItemModel::updateIconTheme()
{
    for(int r = 0; r < rowCount(); ++r)
    {
        static_cast<IrcItem*>(item(r))->updateIconTheme();
    }
}
